@@ -13,9 +13,9 @@
 #include <bonobo/bonobo-file-selector-util.h>
 #include <bonobo/bonobo-ui-main.h>
 
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 static gint
 get_files (gpointer data)
@@ -40,7 +40,7 @@ get_files (gpointer data)
 		g_strfreev (strv);
 	}
 
-	gtk_main_quit ();
+	bonobo_main_quit ();
 
 	return FALSE;
 }
@@ -48,12 +48,13 @@ get_files (gpointer data)
 int
 main (int argc, char *argv[])
 {
+	GnomeProgram *program;
 
 	free (malloc (8));
 
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("test-filesel", VERSION,
+	program = gnome_program_init ("test-filesel", VERSION,
 			    LIBBONOBOUI_MODULE,
 			    argc, argv, NULL);
 
@@ -63,5 +64,7 @@ main (int argc, char *argv[])
 
 	bonobo_main ();
 
+	g_object_unref (program);
+
 	return 0;
 }
